# palabras
(WIP) CLI app to look up Spanish words on Wiktionary

Call from command line like this:
```
> python -m palabras olvidar
olvidar
- (transitive) to forget (be forgotten by)
- (reflexive, intransitive) to forget, elude, escape
- (with de, reflexive, intransitive) to forget, to leave behind
```